==> OpenViewerFX-6.6.14-sources.jar: org/jpedal/objects/acroforms/creation/ComboColorRenderer.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2015 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * ComboColorRenderer.java
 * ---------------
 */
package org.jpedal.objects.acroforms.creation;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

/**
 * set colour on the Cells
 */
public class ComboColorRenderer extends JLabel implements ListCellRenderer {

    Color color = Color.RED;

    ComboColorRenderer(final Color col) {

        color = col;

        setBorder(null);
        setOpaque(true);
    }

    @Override
    public Component getListCellRendererComponent(final JList list, final Object value, final int index,
                                                  final boolean isSelected, final boolean cellHasFocus) {

        setBackground(color);

        if (value == null || ((String) value).isEmpty()) {
            setText(" ");
        } else {
            setText((String) value);
        }

        return this;
    }
}

==> OpenViewerFX-7.9.26-sources.jar: org/jpedal/objects/acroforms/creation/ComboColorRenderer.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2017 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * ComboColorRenderer.java
 * ---------------
 */
package org.jpedal.objects.acroforms.creation;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

/**
 * set colour on the Cells
 */
public class ComboColorRenderer extends JLabel implements ListCellRenderer {

    Color color = Color.RED;

    ComboColorRenderer(final Color col) {

        color = col;

        setBorder(null);
        setOpaque(true);
    }

    @Override
    public Component getListCellRendererComponent(final JList list, final Object rawValue, final int index,
                                                  final boolean isSelected, final boolean cellHasFocus) {

        final String value=(String) rawValue;
        
        setBackground(color);

        if (value == null || value.isEmpty()) {
            setText(" ");
        } else {
            setText(value);
        }

        return this;
    }
}
